@@ -146,21 +146,16 @@ class QiniuStorage(Storage):
         return urljoin("http://" + self.bucket_domain, name)
 
 class QiniuMediaStorage(QiniuStorage):
-    location = settings.MEDIA_ROOT.strip('/')
+    location = 'media'
 
 class QiniuStaticStorage(QiniuStorage):
-    location = settings.STATIC_ROOT.strip('/')
+    location = 'static'
 
 class QiniuFile(File):
     def __init__(self, name, storage, mode):
         self._storage = storage
         self._name = name[len(self._storage.location):].lstrip('/')
         self._mode = mode
-        # if 'b' in mode:
-        #     self._file_class = BytesIO
-        # else:
-        #     self._file_class = StringIO
-        # self.file = self._file_class()
         self.file = BytesIO()
         self._is_dirty = False
         self._is_read = False
